@@ -14,24 +14,24 @@ class MongoConfiguration:
 
     @property
     def password(self) -> str:
-        return self.service_config[MONGO_PASSWORD_CONFIGURATION_KEY]
+        return self.service_config.get(MONGO_PASSWORD_CONFIGURATION_KEY, '')
 
     @property
     def user(self) -> str:
-        return self.service_config[MONGO_USER_CONFIGURATION_KEY]
+        return self.service_config.get(MONGO_USER_CONFIGURATION_KEY, '')
 
     @property
     def connection_string(self) -> str:
-        return self.service_config[MONGO_CUSTOM_CONNECTION_STRING_CONFIGURATION_KEY]
+        return self.service_config.get(MONGO_CUSTOM_CONNECTION_STRING_CONFIGURATION_KEY, '')
 
     @property
     def port(self) -> str:
-        return self.service_config[MONGO_PORT_NAME_CONFIGURATION_KEY]
+        return self.service_config.get(MONGO_PORT_NAME_CONFIGURATION_KEY, '')
 
     @property
     def database_name(self) -> str:
-        return self.service_config[MONGO_DATABASE_NAME_CONFIGURATION_KEY]
+        return self.service_config.get(MONGO_DATABASE_NAME_CONFIGURATION_KEY, '')
 
     @property
     def host_name(self) -> str:
-        return self.service_config[MONGO_HOST_NAME_CONFIGURATION_KEY]
+        return self.service_config.get(MONGO_HOST_NAME_CONFIGURATION_KEY, '')
